local addon = LibStub("AceAddon-3.0"):NewAddon("Battleground", "AceEvent-3.0")
addon:SetDefaultModuleState(false)


-- http://www.wowwiki.com/API_GetMapLandmarkInfo

local landmarks = {
	[1] = {"mine", "neutral"},
	[2] = {"mine", "horde"},
	[3] = {"mine", "alliance"},
	[4] = {"graveyard", "alliance_assaulted"},
	[6] = {"tower", "neutral"},
	[8] = {"graveyard", "neutral"},
	[9] = {"tower", "alliance_assaulted"},
	[10] = {"tower", "horde"},
	[11] = {"tower", "alliance"},
	[12] = {"tower", "horde_assaulted"},
	[13] = {"graveyard", "horde"},
	[14] = {"graveyard", "horde_assaulted"},
	[15] = {"graveyard", "alliance"},
	[16] = {"goldmine", "neutral"},
	[17] = {"goldmine", "alliance_assaulted"},
	[18] = {"goldmine", "alliance"},
	[19] = {"goldmine", "horde_assaulted"},
	[20] = {"goldmine", "horde"},
	[21] = {"lumbermill", "neutral"},
	[22] = {"lumbermill", "alliance_assaulted"},
	[23] = {"lumbermill", "alliance"},
	[24] = {"lumbermill", "horde_assaulted"},
	[25] = {"lumbermill", "horde"},
}
for ti, v in pairs( landmarks ) do
	local x = ti % 16
	local y = floor( ti / 16 )
	v[3] = (x*16)/256
	v[4] = ((x+1)*16)/256
	v[5] = (y*16)/256
	v[6] = ((y+1)*16)/256
end

addon.landmarks = landmarks

-- evt funcs
local CheckZone
local AnalyzeLandmarks
local AnalyzeTimeElapsed
-- random locals
local pois = {}
local oldzone = nil

function AnalyzeLandmarks()
	for i = 1, GetNumMapLandmarks(), 1 do
		local name, desc, ti, x, y = GetMapLandmarkInfo(i)
		local old = pois[name]
		if landmarks[ti] and ( not old or old ~= ti ) then
			pois[name] = ti
			-- print("BG_P", name, unpack(landmarks[ti]))
			addon:SendMessage("Battleground_POIUpdate", name, ti)
		end
	end
end


function AnalyzeTimeElapsed(offset)
	local start = floor(GetBattlefieldInstanceRunTime()/1000)
	if start < offset then
		addon:SendMessage("Battleground_StartTimer", offset - start)
	else
		addon:SendMessage("Battleground_Started", start - offset)
	end
end

function CheckZone()
	if oldzone then
		wipe(pois)
		for name, module in addon:IterateModules() do module:Disable() end
		oldzone = nil
		addon:UnregisterEvent("WORLD_MAP_UPDATE")
	end
	SetMapToCurrentZone()
	local zone = GetMapInfo()
	local module = addon:GetModule(zone, true)
	if module then
		oldzone = zone
		module:Enable()
		addon:RegisterEvent("WORLD_MAP_UPDATE", AnalyzeLandmarks)
		AnalyzeLandmarks()
		AnalyzeTimeElapsed(module.starttimer or 122) -- default to 2 minutes
	end
end

function addon:OnEnable()
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA", CheckZone)
	CheckZone()
end



